/**
 * User websocket controller
 * 
 * @author Pierre Hubert
 */
import * as ws from 'ws';
import { Request } from 'express';
import { RequestHandler } from '../entities/RequestHandler';
import { time } from '../utils/DateUtils';
import { randomStr } from '../utils/CryptUtils';

interface PendingRequests {
	time: number,
	userID: number, 
	token: string
}

// Tokens are valid only 10 seconds after they are generated
const TOKENS_DURATION = 10

export class UserWebSocketController {

	/**
	 * The list of pending connections
	 */
	static pending_list: PendingRequests[] = []

	/**
	 * Clean the list of tokens
	 */
	private static CleanList() {
		// Clean the list
		this.pending_list = this.pending_list
			.filter((l) => l.time + TOKENS_DURATION + 1 > time())
	}

	/**
	 * Get a websocket access token
	 * 
	 * @param h Request handler
	 */
	public static async GetToken(h: RequestHandler) {
		this.CleanList();

		// Generate a temporary token
		const token = randomStr(20);

		// Add the token to the list
		this.pending_list.push({
			time: time(),
			userID: h.getUserId(),
			token: token
		});

		h.send({
			token: token
		});
	}

	/**
	 * Handler user websocket request
	 * 
	 * @param req Associated request
	 * @param ws The socket
	 */
	public static async UserWS(req: Request, ws: ws) {
		this.CleanList();
	}

}

